@@ -2,7 +2,9 @@
  * Command for accessing SPI flash.
  *
  * Copyright (C) 2008 Atmel Corporation
+ * Licensed under the GPL-2 or later.
  */
+
 #include <common.h>
 #include <spi_flash.h>
 
@@ -17,7 +19,48 @@
 
 static struct spi_flash *flash;
 
-static int do_spi_flash_probe(int argc, char *argv[])
+
+/*
+ * This function computes the length argument for the erase command.
+ * The length on which the command is to operate can be given in two forms:
+ * 1. <cmd> offset len  - operate on <'offset',  'len')
+ * 2. <cmd> offset +len - operate on <'offset',  'round_up(len)')
+ * If the second form is used and the length doesn't fall on the
+ * sector boundary, than it will be adjusted to the next sector boundary.
+ * If it isn't in the flash, the function will fail (return -1).
+ * Input:
+ *    arg: length specification (i.e. both command arguments)
+ * Output:
+ *    len: computed length for operation
+ * Return:
+ *    1: success
+ *   -1: failure (bad format, bad address).
+ */
+static int sf_parse_len_arg(char *arg, ulong *len)
+{
+	char *ep;
+	char round_up_len; /* indicates if the "+length" form used */
+	ulong len_arg;
+
+	round_up_len = 0;
+	if (*arg == '+') {
+		round_up_len = 1;
+		++arg;
+	}
+
+	len_arg = simple_strtoul(arg, &ep, 16);
+	if (ep == arg || *ep != '\0')
+		return -1;
+
+	if (round_up_len && flash->sector_size > 0)
+		*len = ROUND(len_arg - 1, flash->sector_size);
+	else
+		*len = len_arg;
+
+	return 1;
+}
+
+static int do_spi_flash_probe(int argc, char * const argv[])
 {
 	unsigned int bus = 0;
 	unsigned int cs;
@@ -27,30 +70,30 @@ static int do_spi_flash_probe(int argc, char *argv[])
 	struct spi_flash *new;
 
 	if (argc < 2)
-		goto usage;
+		return -1;
 
 	cs = simple_strtoul(argv[1], &endp, 0);
 	if (*argv[1] == 0 || (*endp != 0 && *endp != ':'))
-		goto usage;
+		return -1;
 	if (*endp == ':') {
 		if (endp[1] == 0)
-			goto usage;
+			return -1;
 
 		bus = cs;
 		cs = simple_strtoul(endp + 1, &endp, 0);
 		if (*endp != 0)
-			goto usage;
+			return -1;
 	}
 
 	if (argc >= 3) {
 		speed = simple_strtoul(argv[2], &endp, 0);
 		if (*argv[2] == 0 || *endp != 0)
-			goto usage;
+			return -1;
 	}
 	if (argc >= 4) {
-		mode = simple_strtoul(argv[3], &endp, 0);
+		mode = simple_strtoul(argv[3], &endp, 16);
 		if (*argv[3] == 0 || *endp != 0)
-			goto usage;
+			return -1;
 	}
 
 	new = spi_flash_probe(bus, cs, speed, mode);
@@ -63,17 +106,10 @@ static int do_spi_flash_probe(int argc, char *argv[])
 		spi_flash_free(flash);
 	flash = new;
 
-	printf("%u KiB %s at %u:%u is now current device\n",
-			flash->size >> 10, flash->name, bus, cs);
-
 	return 0;
-
-usage:
-	puts("Usage: sf probe [bus:]cs [hz] [mode]\n");
-	return 1;
 }
 
-static int do_spi_flash_read_write(int argc, char *argv[])
+static int do_spi_flash_read_write(int argc, char * const argv[])
 {
 	unsigned long addr;
 	unsigned long offset;
@@ -83,17 +119,17 @@ static int do_spi_flash_read_write(int argc, char *argv[])
 	int ret;
 
 	if (argc < 4)
-		goto usage;
+		return -1;
 
 	addr = simple_strtoul(argv[1], &endp, 16);
 	if (*argv[1] == 0 || *endp != 0)
-		goto usage;
+		return -1;
 	offset = simple_strtoul(argv[2], &endp, 16);
 	if (*argv[2] == 0 || *endp != 0)
-		goto usage;
+		return -1;
 	len = simple_strtoul(argv[3], &endp, 16);
 	if (*argv[3] == 0 || *endp != 0)
-		goto usage;
+		return -1;
 
 	buf = map_physmem(addr, len, MAP_WRBACK);
 	if (!buf) {
@@ -114,13 +150,9 @@ static int do_spi_flash_read_write(int argc, char *argv[])
 	}
 
 	return 0;
-
-usage:
-	printf("Usage: sf %s addr offset len\n", argv[0]);
-	return 1;
 }
 
-static int do_spi_flash_erase(int argc, char *argv[])
+static int do_spi_flash_erase(int argc, char * const argv[])
 {
 	unsigned long offset;
 	unsigned long len;
@@ -128,14 +160,15 @@ static int do_spi_flash_erase(int argc, char *argv[])
 	int ret;
 
 	if (argc < 3)
-		goto usage;
+		return -1;
 
 	offset = simple_strtoul(argv[1], &endp, 16);
 	if (*argv[1] == 0 || *endp != 0)
-		goto usage;
-	len = simple_strtoul(argv[2], &endp, 16);
-	if (*argv[2] == 0 || *endp != 0)
-		goto usage;
+		return -1;
+
+	ret = sf_parse_len_arg(argv[2], &len);
+	if (ret != 1)
+		return -1;
 
 	ret = spi_flash_erase(flash, offset, len);
 	if (ret) {
@@ -144,24 +177,25 @@ static int do_spi_flash_erase(int argc, char *argv[])
 	}
 
 	return 0;
-
-usage:
-	puts("Usage: sf erase offset len\n");
-	return 1;
 }
 
-static int do_spi_flash(cmd_tbl_t *cmdtp, int flag, int argc, char *argv[])
+static int do_spi_flash(cmd_tbl_t *cmdtp, int flag, int argc, char * const argv[])
 {
 	const char *cmd;
+	int ret;
 
 	/* need at least two arguments */
 	if (argc < 2)
 		goto usage;
 
 	cmd = argv[1];
+	--argc;
+	++argv;
 
-	if (strcmp(cmd, "probe") == 0)
-		return do_spi_flash_probe(argc - 1, argv + 1);
+	if (strcmp(cmd, "probe") == 0) {
+		ret = do_spi_flash_probe(argc, argv);
+		goto done;
+	}
 
 	/* The remaining commands require a selected device */
 	if (!flash) {
@@ -170,13 +204,18 @@ static int do_spi_flash(cmd_tbl_t *cmdtp, int flag, int argc, char *argv[])
 	}
 
 	if (strcmp(cmd, "read") == 0 || strcmp(cmd, "write") == 0)
-		return do_spi_flash_read_write(argc - 1, argv + 1);
-	if (strcmp(cmd, "erase") == 0)
-		return do_spi_flash_erase(argc - 1, argv + 1);
+		ret = do_spi_flash_read_write(argc, argv);
+	else if (strcmp(cmd, "erase") == 0)
+		ret = do_spi_flash_erase(argc, argv);
+	else
+		ret = -1;
+
+done:
+	if (ret != -1)
+		return ret;
 
 usage:
-	cmd_usage(cmdtp);
-	return 1;
+	return cmd_usage(cmdtp);
 }
 
 U_BOOT_CMD(
@@ -188,4 +227,6 @@ U_BOOT_CMD(
 	"				  `offset' to memory at `addr'\n"
 	"sf write addr offset len	- write `len' bytes from memory\n"
 	"				  at `addr' to flash at `offset'\n"
-	"sf erase offset len		- erase `len' bytes from `offset'\n");
+	"sf erase offset [+]len		- erase `len' bytes from `offset'\n"
+	"				  `+len' round up `len' to block size"
+);
