@@ -23,6 +23,7 @@
 
 #include "mkimage.h"
 #include <image.h>
+#include <version.h>
 
 static void copy_file(int, const char *, int);
 static void usage(void);
@@ -37,6 +38,7 @@ struct mkimage_params params = {
 	.type = IH_TYPE_KERNEL,
 	.comp = IH_COMP_GZIP,
 	.dtc = MKIMAGE_DEFAULT_DTC_OPTIONS,
+	.imagename = "",
 };
 
 /*
@@ -144,12 +146,14 @@ main (int argc, char **argv)
 {
 	int ifd = -1;
 	struct stat sbuf;
-	unsigned char *ptr;
+	char *ptr;
 	int retval = 0;
 	struct image_type_params *tparams = NULL;
 
 	/* Init Kirkwood Boot image generation/list support */
 	init_kwb_image_type ();
+	/* Init Freescale imx Boot image generation/list support */
+	init_imx_image_type ();
 	/* Init FIT image generation/list support */
 	init_fit_image_type ();
 	/* Init Default image generation/list support */
@@ -198,8 +202,7 @@ main (int argc, char **argv)
 			case 'a':
 				if (--argc <= 0)
 					usage ();
-				params.addr = strtoul (*++argv,
-					(char **)&ptr, 16);
+				params.addr = strtoul (*++argv, &ptr, 16);
 				if (*ptr) {
 					fprintf (stderr,
 						"%s: invalid load address %s\n",
@@ -216,8 +219,7 @@ main (int argc, char **argv)
 			case 'e':
 				if (--argc <= 0)
 					usage ();
-				params.ep = strtoul (*++argv,
-						(char **)&ptr, 16);
+				params.ep = strtoul (*++argv, &ptr, 16);
 				if (*ptr) {
 					fprintf (stderr,
 						"%s: invalid entry point %s\n",
@@ -245,6 +247,9 @@ main (int argc, char **argv)
 			case 'v':
 				params.vflag++;
 				break;
+			case 'V':
+				printf("mkimage version %s\n", PLAIN_VERSION);
+				exit(EXIT_SUCCESS);
 			case 'x':
 				params.xflag++;
 				break;
@@ -281,20 +286,6 @@ NXTARG:		;
 			params.ep += tparams->header_size;
 	}
 
-	/*
-	 * If XIP, ensure the entry point is equal to the load address plus
-	 * the size of the U-Boot header.
-	 */
-	if (params.xflag) {
-		if (params.ep != params.addr + tparams->header_size) {
-			fprintf (stderr,
-				"%s: For XIP, the entry point must be the load addr + %lu\n",
-				params.cmdname,
-				(unsigned long)tparams->header_size);
-			exit (EXIT_FAILURE);
-		}
-	}
-
 	params.imagefile = *argv;
 
 	if (params.fflag){
@@ -603,6 +594,8 @@ usage ()
 		params.cmdname);
 	fprintf (stderr, "       %s [-D dtc_options] -f fit-image.its fit-image\n",
 		params.cmdname);
+	fprintf (stderr, "       %s -V ==> print version information and exit\n",
+		params.cmdname);
 
 	exit (EXIT_FAILURE);
 }
